==> service-client-api-2.4.0-20140917.134654-1-sources.jar: org/gcube/data/analysis/tabulardata/service/tabular/TabularResourceInterface.java <==
package org.gcube.data.analysis.tabulardata.service.tabular;

import java.util.List;

import org.gcube.data.analysis.tabulardata.commons.utils.AuthorizationToken;
import org.gcube.data.analysis.tabulardata.commons.webservice.types.resources.ResourceDescriptor;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.service.exception.InvalidTabularResourceException;
import org.gcube.data.analysis.tabulardata.service.exception.NoSuchTableException;
import org.gcube.data.analysis.tabulardata.service.exception.NoSuchTabularResourceException;

public interface TabularResourceInterface {
	
	public List<TabularResource> getTabularResources();
	
	public List<TabularResource> getTabularResourcesByType(String type);
	
	public TabularResource getTabularResource(TabularResourceId id) throws NoSuchTabularResourceException;
	
	public void removeTabularResource(TabularResourceId id) throws NoSuchTabularResourceException;
	
	public TabularResource createTabularResource();
	
	public Table getLastTable(TabularResourceId id) throws NoSuchTabularResourceException, InvalidTabularResourceException, NoSuchTableException;
	
	public TabularResource share(TabularResourceId tabularResourceId, AuthorizationToken... tokens) throws NoSuchTabularResourceException, SecurityException;
	
	public TabularResource unshare(TabularResourceId tabularResourceId, AuthorizationToken... tokens) throws NoSuchTabularResourceException, SecurityException;

	public List<ResourceDescriptor> getResources(TabularResourceId id) throws NoSuchTabularResourceException;
	
}

==> service-client-api-2.5.2-20150313.105405-4-sources.jar: org/gcube/data/analysis/tabulardata/service/tabular/TabularResourceInterface.java <==
package org.gcube.data.analysis.tabulardata.service.tabular;

import java.util.List;

import org.gcube.data.analysis.tabulardata.commons.utils.AuthorizationToken;
import org.gcube.data.analysis.tabulardata.commons.webservice.types.resources.ResourceDescriptor;
import org.gcube.data.analysis.tabulardata.model.resources.ResourceType;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.service.exception.InvalidTabularResourceException;
import org.gcube.data.analysis.tabulardata.service.exception.NoSuchTableException;
import org.gcube.data.analysis.tabulardata.service.exception.NoSuchTabularResourceException;

public interface TabularResourceInterface {
	
	public List<TabularResource> getTabularResources();
	
	public List<TabularResource> getTabularResourcesByType(String type);
	
	public TabularResource getTabularResource(TabularResourceId id) throws NoSuchTabularResourceException;
	
	public void removeTabularResource(TabularResourceId id) throws NoSuchTabularResourceException;
	
	public TabularResource createTabularResource();
	
	public TabularResource createFlow();
	
	public Table getLastTable(TabularResourceId id) throws NoSuchTabularResourceException, InvalidTabularResourceException, NoSuchTableException;
	
	public TabularResource share(TabularResourceId tabularResourceId, AuthorizationToken... tokens) throws NoSuchTabularResourceException, SecurityException;
	
	public TabularResource unshare(TabularResourceId tabularResourceId, AuthorizationToken... tokens) throws NoSuchTabularResourceException, SecurityException;

	public List<ResourceDescriptor> getResources(TabularResourceId id) throws NoSuchTabularResourceException;
	
	public List<ResourceDescriptor> getResourcesByType(TabularResourceId id, ResourceType type) throws NoSuchTabularResourceException;

	ResourceDescriptor removeResurce(long resourceId);
	
}
